@@ -1,18 +1,18 @@
-# $Id: Constraints.pm 1198 2006-06-03 02:32:37Z claco $
+# $Id: Constraints.pm 1335 2006-07-15 02:43:12Z claco $
 package Handel::Constraints;
 use strict;
 use warnings;
-use vars qw(@EXPORT_OK %EXPORT_TAGS);
+use vars qw/@EXPORT_OK %EXPORT_TAGS/;
 
 BEGIN {
     use base 'Exporter';
     use Handel;
-    use Handel::Constants qw(:cart :checkout :order);
+    use Handel::Constants qw/:cart :checkout :order/;
     use Handel::Exception;
-    use Handel::L10N qw(translate);
+    use Handel::L10N qw/translate/;
 };
 
-@EXPORT_OK = qw(&constraint_quantity
+@EXPORT_OK = qw/&constraint_quantity
                 &constraint_price
                 &constraint_uuid
                 &constraint_cart_type
@@ -20,7 +20,7 @@ BEGIN {
                 &constraint_currency_code
                 &constraint_checkout_phase
                 &constraint_order_type
-);
+/;
 
 %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -136,42 +136,63 @@ Handel::Constraints - Common database constraints used to validate input data
 
 =head1 SYNOPSIS
 
-    use Handel::Constraints qw(constraint_quantity);
-
+    use Handel::Constraints qw/constraint_quantity/;
+    
     my $qty = 'bogus-1';
-
-    if (constraint_quantity($qty) {
+    
+    if (constraint_quantity($qty)) {
         print 'invalid quantity';
     };
 
 =head1 DESCRIPTION
 
-C<Handel::Constraints> contains a set of functions used to validate data
-submitted by users into Handel objects. By default, C<Handel::Constraints>
-doesn't export anything. Use the export tags to export groups of functions, or
-specify the exact methods you are interested in using. See L<Exporter> for more
+Handel::Constraints contains a set of functions used to validate data submitted
+by users into Handel objects. By default, Handel::Constraints doesn't export
+anything. Use the export tags to export groups of functions, or specify the
+exact methods you are interested in using. See L<Exporter|Exporter> for more
 information on using export tags.
 
 =head1 FUNCTIONS
 
 =head2 constraint_quantity
 
-Returns 1 if the value passed is a numeric, non-negative value, otherwise
- it returns C<undef>.
+=over
+
+=item Arguments: $quantity
+
+=back
+
+Returns 1 if the value passed is a numeric, non-negative value that is less
+than or equal HandelMaxQuantity. Otherwise it returns C<undef>.
+
+See L<Handel::ConfigReader|Handel::ConfigReader> for more information on
+HandelMaxQuantity and HandelMaxQuantityAction.
 
 =head2 constraint_price
 
+=over
+
+=item Arguments: $price
+
+=back
+
 Returns 1 if the value passed is a numeric, non-negative value between 0 and
 99999.99, otherwise it returns C<undef>.
 
 =head2 constraint_uuid
 
+=over
+
+=item Arguments: $string
+
+=back
+
 Returns 1 if the value passed is conforms to the GUID/UUID format, otherwise it
 returns C<undef>. Currently, this does B<not> expect the brackets around the
 value.
 
     constraint_uuid( '11111111-1111-1111-1111-111111111111' ); # 1
-
+    
     constraint_uuid('{11111111-1111-1111-1111-111111111111}'); # undef
 
 This will probably change in the future, or some sort of stripping of the
@@ -179,32 +200,62 @@ brackets may occur.
 
 =head2 constraint_cart_type
 
+=over
+
+=item Arguments: $type
+
+=back
+
 Returns 1 if the value passed is C<CART_TYPE_SAVED> or C<CART_TYPE_TEMP>,
 otherwise it returns C<undef>.
 
 =head2 constraint_currency_code
 
-Returns 1 if the value passed is considered a 3 letter currency code.
-If L<Locale::Currency> is installed, it will verify the 3 letter code is
-actually a valid currency code.
+=over
 
-If C<Locale::Currency> is not installed, it simply checks that the code
-conforms to:
+=item Arguments: $code
+
+=back
+
+Returns 1 if the value passed is considered a 3 letter currency code.
+If L<Locale::Currency|Locale::Currency> is installed, it will verify the 3
+letter code is actually a valid currency code.
+
+If Locale::Currency is not installed, it simply checks that the code conforms
+to:
 
     /^[A-Z]{3}$/
 
 =head2 constraint_checkout_phase
 
+=over
+
+=item Arguments: $phase
+
+=back
+
 Returns 1 if the value passed is one of the C<CHECKOUT_PHASE_*> constants,
 otherwise it returns C<undef>.
 
 =head2 constraint_order_type
 
+=over
+
+=item Arguments: $type
+
+=back
+
 Returns 1 if the value passed is C<ORDER_TYPE_SAVED> or C<ORDER_TYPE_TEMP>,
 otherwise it returns C<undef>.
 
 =head2 constraint_cart_name
 
+=over
+
+=item Arguments: $name
+
+=back
+
 Returns 0 if the cart type is C<CART_TYPE_SAVED> and the name is undefined,
 otherwise it returns 1.
 
@@ -212,9 +263,9 @@ otherwise it returns 1.
 
 =head2 :all
 
-Exports all functions into the classes namespace.
+Exports all functions into the callers namespace.
 
-    use Handel::Constraints qw(:all);
+    use Handel::Constraints qw/:all/;
 
 =head1 AUTHOR
 
